pub fn handle_integer_type(
handle: &GpuTensorHandle,
) -> Option<IntegerElementType>Expand description
Look up the exact native integer class stored by a GPU tensor handle.
pub fn handle_integer_type(
handle: &GpuTensorHandle,
) -> Option<IntegerElementType>Look up the exact native integer class stored by a GPU tensor handle.