pub struct GpuTensorHandle {
pub shape: Vec<usize>,
pub device_id: u32,
pub buffer_id: u64,
pub descriptor: GpuTensorDescriptor,
}Fields
shape: Vec<usize>device_id: u32Stable provider/device namespace identifier. Distinct live provider instances that can own handles must use distinct identifiers because provider routing is keyed by this value.
buffer_id: u64descriptor: GpuTensorDescriptorImplementations
Sourceimpl GpuTensorHandle
impl GpuTensorHandle
pub fn new(shape: Vec<usize>, device_id: u32, buffer_id: u64) -> Self
pub fn with_numeric_descriptor( self, element_type: NumericElementType, storage: GpuTensorStorage, ) -> Self
pub fn with_provenance(self, provenance: GpuHandleProvenance) -> Self