pub struct ProviderModeTiedSets {
pub values: HostTensorOwned,
pub offsets: Vec<usize>,
pub counts: Vec<usize>,
}Expand description
Sorted tied modal values for each output slice.
values stores all tied values for all slices in ascending per-slice order.
offsets and counts are one entry per output slice and describe the
slice-local range inside values. Runtime callers convert this ragged
representation into MATLAB cell output C.
Fields
values: HostTensorOwnedoffsets: Vec<usize>counts: Vec<usize>Trait Implementations
Sourceimpl Clone for ProviderModeTiedSets
impl Clone for ProviderModeTiedSets
Sourcefn clone(&self) -> ProviderModeTiedSets
fn clone(&self) -> ProviderModeTiedSets
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderModeTiedSets
impl Debug for ProviderModeTiedSets
Sourceimpl<'de> Deserialize<'de> for ProviderModeTiedSets
impl<'de> Deserialize<'de> for ProviderModeTiedSets
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProviderModeTiedSets
impl PartialEq for ProviderModeTiedSets
Sourceimpl Serialize for ProviderModeTiedSets
impl Serialize for ProviderModeTiedSets
impl StructuralPartialEq for ProviderModeTiedSets